@@ -6,10 +6,19 @@
 import os
 from dataclasses import dataclass
 from pathlib import Path
-from typing import Any, Callable, Iterable, Optional, Protocol, Union
+from typing import (
+    Any,
+    Callable,
+    Generic,
+    Iterable,
+    Optional,
+    Protocol,
+    TypeVar,
+    Union,
+)
 from urllib.parse import urlsplit
 
-from greenbone.feed.sync.errors import ConfigFileError
+from greenbone.feed.sync.errors import ConfigError, ConfigFileError
 from greenbone.feed.sync.helper import DEFAULT_FLOCK_WAIT_INTERVAL
 from greenbone.feed.sync.rsync import (
     DEFAULT_RSYNC_COMPRESSION_LEVEL,
@@ -34,18 +43,7 @@ def maybe_int(value: Optional[str]) -> Union[int, str, None]:
     return value
 
 
-DEFAULT_VERSION = "22.04"
-
-DEFAULT_NOTUS_URL_PATH = f"/vulnerability-feed/{DEFAULT_VERSION}/vt-data/notus/"
-DEFAULT_NASL_URL_PATH = f"/vulnerability-feed/{DEFAULT_VERSION}/vt-data/nasl/"
-DEFAULT_SCAP_DATA_URL_PATH = f"/vulnerability-feed/{DEFAULT_VERSION}/scap-data/"
-DEFAULT_CERT_DATA_URL_PATH = f"/vulnerability-feed/{DEFAULT_VERSION}/cert-data/"
-DEFAULT_GVMD_DATA_URL_PATH = f"/data-feed/{DEFAULT_VERSION}/"
-DEFAULT_REPORT_FORMATS_URL_PATH = (
-    f"/data-feed/{DEFAULT_VERSION}/report-formats/"
-)
-DEFAULT_SCAN_CONFIGS_URL_PATH = f"/data-feed/{DEFAULT_VERSION}/scan-configs/"
-DEFAULT_PORT_LISTS_URL_PATH = f"/data-feed/{DEFAULT_VERSION}/port-lists/"
+DEFAULT_FEED_RELEASE = "24.10"
 
 DEFAULT_DESTINATION_PREFIX = "/var/lib/"
 
@@ -53,14 +51,6 @@ DEFAULT_NASL_PATH = "openvas/plugins"
 DEFAULT_NOTUS_PATH = "notus"
 DEFAULT_SCAP_DATA_PATH = "gvm/scap-data"
 DEFAULT_CERT_DATA_PATH = "gvm/cert-data"
-DEFAULT_GVMD_DATA_PATH = f"gvm/data-objects/gvmd/{DEFAULT_VERSION}/"
-DEFAULT_REPORT_FORMATS_PATH = (
-    f"gvm/data-objects/gvmd/{DEFAULT_VERSION}/report-formats"
-)
-DEFAULT_SCAN_CONFIGS_PATH = (
-    f"gvm/data-objects/gvmd/{DEFAULT_VERSION}/scan-configs"
-)
-DEFAULT_PORT_LISTS_PATH = f"gvm/data-objects/gvmd/{DEFAULT_VERSION}/port-lists"
 
 DEFAULT_GVMD_LOCK_FILE_PATH = "gvm/feed-update.lock"
 DEFAULT_OPENVAS_LOCK_FILE_PATH = "openvas/feed-update.lock"
@@ -75,15 +65,36 @@ DEFAULT_USER = "gvm"
 
 DEFAULT_VERBOSITY = 2
 
+T = TypeVar("T")
+ValuesDict = dict[str, Any]
+DefaultValueCallable = Callable[[ValuesDict], Any]
+ValueTypeCallable = Callable[[Any], T]
+
+
+def resolve_gvmd_data_destination(values: ValuesDict) -> str:
+    path = "gvm/data-objects/gvmd"
+    feed_release: str = values.get("feed-release")  # type: ignore[assignment]
+    try:
+        str_major, str_minor = feed_release.split(".")[:2]
+        major, minor = int(str_major), int(str_minor)
+    except ValueError as e:
+        raise ConfigError(f"Invalid feed release format: {feed_release}") from e
+
+    return (
+        f"{values['destination-prefix']}/{path}"
+        if major >= 24 and minor >= 10
+        else f"{values['destination-prefix']}/{path}/{feed_release}"
+    )
+
 
 @dataclass
-class Setting:
+class Setting(Generic[T]):
     config_key: str
     environment_key: str
     default_value: Union[str, int, bool, None]
-    value_type: Callable
+    value_type: ValueTypeCallable[T]
 
-    def resolve(self, values: dict[str, Any]) -> Any:
+    def resolve(self, values: ValuesDict) -> Optional[T]:
         value: Any
         if self.environment_key in os.environ:
             value = os.environ.get(self.environment_key)
@@ -96,13 +107,13 @@ class Setting:
 
 
 @dataclass
-class DependentSetting:
+class DependentSetting(Generic[T]):
     config_key: str
     environment_key: str
-    default_value: Callable
-    value_type: Callable
+    default_value: DefaultValueCallable
+    value_type: ValueTypeCallable[T]
 
-    def resolve(self, values: dict[str, Any]) -> Any:
+    def resolve(self, values: ValuesDict) -> Optional[T]:
         if self.environment_key in os.environ:
             value = os.environ.get(self.environment_key)
         elif self.config_key in values:
@@ -171,20 +182,26 @@ _SETTINGS = (
         DEFAULT_ENTERPRISE_KEY_PATH,
         Path,
     ),
+    Setting(
+        "feed-release",
+        "GREENBONE_FEED_SYNC_FEED_RELEASE",
+        DEFAULT_FEED_RELEASE,
+        str,
+    ),
 )
 
-# pylint: disable=line-too-long
+
 _DEPENDENT_SETTINGS = (
     DependentSetting(
         "gvmd-data-destination",
         "GREENBONE_FEED_SYNC_GVMD_DATA_DESTINATION",
-        lambda values: f"{values['destination-prefix']}/{DEFAULT_GVMD_DATA_PATH}",  # noqa: E501
+        resolve_gvmd_data_destination,
         Path,
     ),
     DependentSetting(
         "gvmd-data-url",
         "GREENBONE_FEED_SYNC_GVMD_DATA_URL",
-        lambda values: f"{values['feed-url']}{DEFAULT_GVMD_DATA_URL_PATH}",
+        lambda values: f"{values['feed-url']}/data-feed/{values['feed-release']}/",
         str,
     ),
     DependentSetting(
@@ -196,7 +213,7 @@ _DEPENDENT_SETTINGS = (
     DependentSetting(
         "notus-url",
         "GREENBONE_FEED_SYNC_NOTUS_URL",
-        lambda values: f"{values['feed-url']}{DEFAULT_NOTUS_URL_PATH}",
+        lambda values: f"{values['feed-url']}/vulnerability-feed/{values['feed-release']}/vt-data/notus/",
         str,
     ),
     DependentSetting(
@@ -208,7 +225,7 @@ _DEPENDENT_SETTINGS = (
     DependentSetting(
         "nasl-url",
         "GREENBONE_FEED_SYNC_NASL_URL",
-        lambda values: f"{values['feed-url']}{DEFAULT_NASL_URL_PATH}",
+        lambda values: f"{values['feed-url']}/vulnerability-feed/{values['feed-release']}/vt-data/nasl/",
         str,
     ),
     DependentSetting(
@@ -220,7 +237,7 @@ _DEPENDENT_SETTINGS = (
     DependentSetting(
         "scap-data-url",
         "GREENBONE_FEED_SYNC_SCAP_DATA_URL",
-        lambda values: f"{values['feed-url']}{DEFAULT_SCAP_DATA_URL_PATH}",
+        lambda values: f"{values['feed-url']}/vulnerability-feed/{values['feed-release']}/scap-data/",
         str,
     ),
     DependentSetting(
@@ -232,43 +249,43 @@ _DEPENDENT_SETTINGS = (
     DependentSetting(
         "cert-data-url",
         "GREENBONE_FEED_SYNC_CERT_DATA_URL",
-        lambda values: f"{values['feed-url']}{DEFAULT_CERT_DATA_URL_PATH}",
+        lambda values: f"{values['feed-url']}/vulnerability-feed/{values['feed-release']}/cert-data/",
         str,
     ),
     DependentSetting(
         "report-formats-destination",
         "GREENBONE_FEED_SYNC_REPORT_FORMATS_DESTINATION",
-        lambda values: f"{values['destination-prefix']}/{DEFAULT_REPORT_FORMATS_PATH}",  # noqa: E501
+        lambda values: f"{values['gvmd-data-destination']}/report-formats",
         Path,
     ),
     DependentSetting(
         "report-formats-url",
         "GREENBONE_FEED_SYNC_REPORT_FORMATS_URL",
-        lambda values: f"{values['feed-url']}{DEFAULT_REPORT_FORMATS_URL_PATH}",  # noqa: E501
+        lambda values: f"{values['feed-url']}/data-feed/{values['feed-release']}/report-formats/",  # noqa: E501
         str,
     ),
     DependentSetting(
         "scan-configs-destination",
         "GREENBONE_FEED_SYNC_SCAN_CONFIGS_DESTINATION",
-        lambda values: f"{values['destination-prefix']}/{DEFAULT_SCAN_CONFIGS_PATH}",  # noqa: E501
+        lambda values: f"{values['gvmd-data-destination']}/scan-configs",
         Path,
     ),
     DependentSetting(
         "scan-configs-url",
         "GREENBONE_FEED_SYNC_SCAN_CONFIGS_URL",
-        lambda values: f"{values['feed-url']}{DEFAULT_SCAN_CONFIGS_URL_PATH}",
+        lambda values: f"{values['feed-url']}/data-feed/{values['feed-release']}/scan-configs/",  # noqa: E501
         str,
     ),
     DependentSetting(
         "port-lists-destination",
         "GREENBONE_FEED_SYNC_PORT_LISTS_DESTINATION",
-        lambda values: f"{values['destination-prefix']}/{DEFAULT_PORT_LISTS_PATH}",  # noqa: E501
+        lambda values: f"{values['gvmd-data-destination']}/port-lists",
         Path,
     ),
     DependentSetting(
         "port-lists-url",
         "GREENBONE_FEED_SYNC_PORT_LISTS_URL",
-        lambda values: f"{values['feed-url']}{DEFAULT_PORT_LISTS_URL_PATH}",
+        lambda values: f"{values['feed-url']}/data-feed/{values['feed-release']}/port-lists/",  # noqa: E501
         str,
     ),
     DependentSetting(
@@ -299,7 +316,7 @@ class Config:
     """
 
     def __init__(self) -> None:
-        self._config: dict[str, Any] = {}
+        self._config: ValuesDict = {}
 
     def load_from_config_file(self, config_file: Path) -> None:
         try:
